@@ -13,14 +13,13 @@ use Config;
 
 # ABSTRACT: Translate an IDL source to an AST
 
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 
 use Carp qw/carp croak/;
 use Marpa::R2 qw//;
 use File::Basename qw/basename fileparse/;
-use File::Spec::Functions qw/case_tolerant rel2abs/;
-use File::Slurp qw/read_file/;
+use File::Spec::Functions qw/case_tolerant rel2abs catdir/;
 
 our $BLESS_PACKAGE = 'IDL::AST';
 our $DATA = do {local $/; <DATA>};
@@ -42,7 +41,7 @@ sub new {
 
 
 sub parse {
-    my ($self, $path, $hashOptPtr) = @_;
+    my ($self, $input, $hashOptPtr) = @_;
     #
     # Parameters check
     #
@@ -55,26 +54,38 @@ sub parse {
         delete($hashOptPtr->{$_});
       }
     }
-    #
-    # IDL wants the filename to end with .idl
-    #
-    my ($filename, $directories, $suffix) = fileparse($path, qr/\.[^.]*/);
-    if ((  case_tolerant() && (lc($suffix) ne '.idl')) ||
-        (! case_tolerant() && (   $suffix  ne '.idl'))) {
-      carp "$path does not end with .idl";
+    my $datap;
+    if (! ref($input)) {
+      #
+      # Assume this is a filename
+      # IDL wants the filename to end with .idl
+      #
+      my ($filename, $directories, $suffix) = fileparse($input, qr/\.[^.]*/);
+      if ((  case_tolerant() && (lc($suffix) ne '.idl')) ||
+          (! case_tolerant() && (   $suffix  ne '.idl'))) {
+        carp "$input does not end with .idl";
+      }
+      #
+      # Load data
+      #
+      open(my $fh, '<', $input) || croak "Failed to open $input, $!";
+      my $data = do { local $/; <$fh> };
+      close($fh) || warn "Failed to close $input, $!";
+      $datap = \$data;
+    } else {
+      #
+      # Assume this is the data to parse
+      #
+      $datap = $input;
     }
     #
-    # Load data
-    #
-    my $data = read_file($path);
-    #
-    # Regonizer
+    # Recognizer
     #
     my $recce = Marpa::R2::Scanless::R->new({grammar => $G,
                                              # trace_terminals => 1,
                                              semantics_package => 'MarpaX::Languages::IDL::AST::Value',
                                              %{$hashOptPtr}});
-    $recce->read(\$data);
+    $recce->read($datap);
     #
     # AST value
     #
@@ -112,21 +123,36 @@ sub generate {
     my ($self, $ast, $template, $targetOptionHashp) = @_;
 
     $ast               //= $self->ast();
-    $template          //= 'moosex.tt2';
+    $template          //= 'perl5.tt2';
     $targetOptionHashp //= {};
 
+    #
+    # We provide a default style only if this is a template we know about
+    #
+    my $style  = $targetOptionHashp->{style};
+    my $addDefaultStyleInIncludePath = '';
+    my $packageDist = __PACKAGE__;
+    $packageDist =~ s/::/-/g;
+    my $distDir = dist_dir($packageDist);
+    if (! defined($style)) {
+      if ($template eq 'perl5.tt2') {
+        $style = 'Moose';
+        $addDefaultStyleInIncludePath = catdir($distDir, 'perl5', 'style', $style);
+      }
+    }
+
     if (ref($targetOptionHashp) ne 'HASH') {
 	croak '3rd argument must be a pointer to HASH';
     }
 
-    my $packageDist = __PACKAGE__;
-    $packageDist =~ s/::/-/g;
-    my $distDir = dist_dir($packageDist);
     my $ttOptionHashp = $targetOptionHashp->{tt};
     $ttOptionHashp->{STRICT} //= 1;
     $ttOptionHashp->{DELIMITER} //= $Config{path_sep};
     $ttOptionHashp->{INCLUDE_PATH} //= '';
     $ttOptionHashp->{INCLUDE_PATH} .= $ttOptionHashp->{DELIMITER} . $distDir;
+    if ($addDefaultStyleInIncludePath) {
+      $ttOptionHashp->{INCLUDE_PATH} .= $ttOptionHashp->{DELIMITER} . $addDefaultStyleInIncludePath;
+    }
     $ttOptionHashp->{INTERPOLATE} //= 1;
     $ttOptionHashp->{EVAL_PERL} //= 1;
     $ttOptionHashp->{PRE_CHOMP} //= CHOMP_NONE;
@@ -145,7 +171,7 @@ sub generate {
     #
     $ttVarsHashp->{ast} //= $ast;
     $ttVarsHashp->{nativeFloat} = $targetOptionHashp->{nativeFloat} // 1;
-    $ttVarsHashp->{style} = $targetOptionHashp->{style} // 'Moose';
+    $ttVarsHashp->{style} = $style;
 
     $self->{_output} = '';
     $tt->process($template, $ttVarsHashp, \$self->{_output}) || croak $tt->error();
@@ -167,7 +193,7 @@ MarpaX::Languages::IDL::AST - Translate an IDL source to an AST
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -240,7 +266,7 @@ AST as produced by the method $self->parse(). Default to $self->ast().
 
 =item $template
 
-Template-Toolkit template name. Default to 'moosex.tt2', available in this distribution.
+Template-Toolkit template name. Default to 'perl5.tt2', available in this distribution.
 
 =item $targetOptionHashp
 
